Correct any potential formatting issues in a completed standards checklist
Examples
f <- tempfile (fileext = ".md")
if (FALSE) { # \dontrun{
srr_stats_checklist (category = "regression", filename = f)
chk <- srr_stats_checklist_check (f)
} # }
Correct any potential formatting issues in a completed standards checklist
f <- tempfile (fileext = ".md")
if (FALSE) { # \dontrun{
srr_stats_checklist (category = "regression", filename = f)
chk <- srr_stats_checklist_check (f)
} # }